@@ -30,7 +30,8 @@ class IxNetworkApi(Api):
                  port='11009',
                  username='admin',
                  password='admin',
-                 license_servers=[]):
+                 license_servers=[],
+                 log_level='info'):
         """Create a session
         - address (str): The ip address of the TestPlatform to connect to 
         where test sessions will be created or connected to.
@@ -44,6 +45,7 @@ class IxNetworkApi(Api):
         self._username = username
         self._password = password
         self._license_servers = license_servers
+        self._log_level = log_level
         self._running_config = None
         self._config = None
         self._assistant = None
@@ -225,7 +227,7 @@ class IxNetworkApi(Api):
                 RestPort=self._port,
                 UserName=self._username,
                 Password=self._password,
-                LogLevel=SessionAssistant.LOGLEVEL_INFO)
+                LogLevel=self._log_level)
             self._ixnetwork = self._assistant.Session.Ixnetwork
             self._vport = self._ixnetwork.Vport
             self._topology = self._ixnetwork.Topology
@@ -267,7 +269,15 @@ class IxNetworkApi(Api):
             if item.Name not in valid_names:
                 invalid_names.append(item.Name)
         if len(invalid_names) > 0:
-            ixn_obj.find(Name='^(%s)$' % '|'.join(invalid_names)).remove()
+            if ixn_obj._SDM_NAME == 'trafficItem':
+                # can't remove traffic items that are started
+                ixn_obj.find(Name='^(%s)$' % '|'.join(invalid_names), State='^start')
+                if len(ixn_obj) > 0:
+                    ixn_obj.StopStatelessTrafficBlocking()
+                    time.sleep(2)
+            ixn_obj.find(Name='^(%s)$' % '|'.join(invalid_names))
+            if len(ixn_obj) > 0:
+                ixn_obj.remove()
 
     def _get_topology_name(self, port_name):
         return 'Topology %s' % port_name
@@ -364,7 +374,7 @@ class IxNetworkApi(Api):
                     'filters': traffic_item_filters
                 }, {
                     'child': 'highLevelStream',
-                    'properties': ['txPortName', 'rxPortNames'],
+                    'properties': ['txPortName', 'rxPortNames', 'state'],
                     'filters': []
                 }],
                 'inlines': []
